/*
 * Java
 *
 * Copyright 2019 MicroEJ Corp. All rights reserved.
 * For demonstration purpose only.
 * MicroEJ Corp. PROPRIETARY. Use is subject to license terms.
 */
package com.microej.example.bluetooth.hello;

import ej.bluetooth.BluetoothDevice;
import ej.bluetooth.BluetoothPermissions;
import ej.bluetooth.BluetoothProperties;
import ej.bluetooth.BluetoothStatus;
import ej.bluetooth.BluetoothUuid;
import ej.bluetooth.util.server.BasicServerCharacteristic;
import ej.bon.Util;

/**
 * A characteristic for the hello world message.
 */
public class HelloWorldCharacteristic extends BasicServerCharacteristic {

	private static final BluetoothUuid UUID = new BluetoothUuid("ea03d902-4966-49f5-9b52-4bc474ddc077"); //$NON-NLS-1$

	/**
	 * Instantiates an {@link HelloWorldCharacteristic}.
	 */
	public HelloWorldCharacteristic() {
		super(UUID, BluetoothProperties.READ | BluetoothProperties.NOTIFY, BluetoothPermissions.READ);
	}

	@Override
	public void onReadRequest(BluetoothDevice device) {
		HelloWorldBackgroundService.LOGGER.info("Sending read response to " + device); //$NON-NLS-1$
		sendReadResponse(device, BluetoothStatus.OK, getMessage().getBytes());
	}

	@Override
	public void onNotify(BluetoothDevice device) {
		HelloWorldBackgroundService.LOGGER.info("Sending notification to " + device); //$NON-NLS-1$
		sendNotification(device, getMessage().getBytes(), false);
	}

	private String getMessage() {
		return "Uptime " + (Util.platformTimeMillis() / 1000) + "s"; //$NON-NLS-1$
	}
}
